package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0`!``````````(`"``!````D!U``#0````4P@``!1``$#0`(``)
M`"@`(@`A``8````T````-`!``#0`0``@`0``(`$```4````$`````P```%0!
M``!4`4``5`%```T````-````!`````$```````!PA`$``(0!0`"$`4``&```
M`!@````$````!`````$```````````!`````0``$7```!%P```4```````$`
M`0````!@````8$$``&!!`"1=``"0;0``!@```````0`"````P`$``,`!0`#`
M`4``0`$``$`!```'````!`````0```!D`0``9`%``&0!0``@````(`````0`
M```$````!````)P!``"<`4``G`%``"0````D````!`````0`````````````
M````````````````````````````!````"]L:6(O;&0N<V\N,0`````$````
M$`````$```!'3E4```````(````&````&@```/8!`+(`````````````````
M````X#Q"``0````4`````P```$=.50#/H.%&`8GZJ/]Q>^NU!2`VK)A=`0$`
M``!"`````0```#("```!````/0(```$```!'`@```0```*@"```!````SP,`
M``$```#I`P``#````(@60``-````X%=```0``````T``!0```$P-0``&````
M3`9```H```!L!0``"P```!`````6``!PX+M!`!4``````````P```/"\00`1
M````2!1``!(````X````$P````@````!``!P`0````4``'`"````!@``<```
M0``*``!P"0```!$``'!P````$@``<"$````3``!P;0```!0````1````%P``
M`(`40``"````"`(``#(``'#DNT$`_O__;Y@30`#___]O`P```/#__V^X$D``
M````````````````````````````````````````````````````````````
M````80```'````````````````````!A``````````````!5`````````#\`
M``!D````*0`````````N````*````"P`````````'````$X````#````-@``
M`!,````Q````/@```%H``````````````!L```!!````90``````````````
M:0```%,````]````60````````!'````9@```%P```!(`````````$H`````
M````4``````````W````:`````````!>````3P```!X````S````)@``````
M````````3````&X```!#````-```````````````10`````````Y````````
M`%\```!L``````````T```!G````8P```%T````U````8@``````````````
M`0```"$````[````"0```&`````P````20````````!K````6```````````
M````.@```$L`````````/````%0````X````:@```%8```!"````````````
M````````````````````````````````````````"```````````````"@``
M````````````#```````````````````````````````!P``````````````
M``````0````6````````````````````````````````````````````````
M`````````!T````?`````````````````````````!H`````````````````
M``!O````"P```!<````&`````````"L````B````$@```",`````````)0``
M```````0`````````"\```````````````````!M`````````"H````.````
M$0`````````%````)````$8`````````````````````````30`````````R
M````%``````````9``````````````!$````4@``````````````)P``````
M`````````@``````````````40````````````````````````!;````%0``
M`"T```!7``````````````!```````````\````8````(```````````````
M```````````1````D%9```@````2``\`"P,`````````````$@```",$``#(
M.T``"````!(`#P#=`@`````````````2````4@````$`````````$P#Q_W@"
M`````````````!(```"#!```(&!!```````A`!<`Q0,``#"]00`$````$0`<
M`$8$`````````````!(```"^`P``.+U!``0````1`!P`\@(`````````````
M$@```#0$``#P04``.````!(`#P"1```````````````2````;0,`````````
M````$@```-<#``!`O4$`!````!$`'`!/!```/%5``+0````2``\`)`(`````
M````````$@```&T```"@%T```````!((```%!```)+U!```````0`/'_00,`
M````````````$@```'T``````````````!(```",```````````````2````
M&P```.!70```````$@`1`(0#`````````````!(```"5`P`````````````2
M````&0(``$2]00`$````$0`<`.L"`````````````!(```"6````````````
M```2````#`(``$B]00`!````$0`<`+H"`````````````!(````9`P``````
M```````2````_@$`````````````$@```%L$``#0/4``1````!(`#P!H!```
M%#Y``'`!```2``\`=`0``(A#0`!X#0``$@`/`.P!`````````````!(```"D
M```````````````2````W@$`````````````$@```'T"`````````````!(`
M``#6`@`````````````2````RP$`````````````$@```+8#````````````
M`!(```#7`0`````````````2````@00``"!@00``````$0`7`+L!````````
M`````!(````J`P`````````````2````IP,``"!80``$````$0`2`/X#```@
M8$$``````!``%P".!```"#M``,`````2``\`K`$``$R]00`3````$0`<`!(#
M`````````````!(```"O```````````````2````?0,`````````````$@``
M`"\#`````````````!(```!C````X+M!```````1`!@`<0(`````````````
M$@```)\!`````````````!(````!````F%9``+`````2``\`B@$`````````
M````$@```'\!`````````````!(```#D`@`````````````2````1P,`````
M````````$@```'0#`````````````!(```"^````H!E````````2"```'@0`
M`)#-00``````$`#Q_X4"`````````````!(```!-`P`````````````2````
MT0``````````````$@```"(#`````````````!(```!S`0`````````````2
M````I`0``(0_0`#X`0``$@`/`-\``````````````!(```!B`0``````````
M```2````SP(`````````````$@````P$```DO4$``````!``\?^Q!```8#I`
M`$`````2``\`+@```#`;0`!4`@``$@`/`+D$``#@/$(``````!,`\?_"!```
MD!U````````2``\`R@0`````````````$0```-D$``#0.T````(``!(`#P!4
M`P`````````````2````Y@0``"A"0`!@`0``$@`/`/@$``!\04``=````!(`
M#P!4`0`````````````2````Z@```%`:0```````$@@```8%``#P54``4```
M`!(`#P#W`P``,!M````````0``\`0`$`````````````(````#$!````````
M`````!(```#[```````````````2````90,`````````````$@```%L#````
M`````````!(````$`0``\+Q!```````1`/'_&`0``"2]00``````$`#Q_QH!
M`````````````!(```#Z`@`````````````2````QP,``#"]00`$````(0`<
M`#<#`````````````!(```!=`@`````````````2````G`,`````````````
M$@```+,$``"(%D```````!(`#0!7`@`````````````2`````@,`````````
M````$@```"(%````44``/`0``!(`#P"R`@`````````````2````U00``.`\
M0@``````$`#Q_\$"`````````````!(````A````P%=````````2````,P``
M````````````(@```)8"``"P5T```````!(`````7U]L:6)C7V-S=5]I;FET
M`%]?;&EB8U]C<W5?9FEN:0!?7VQI8F-?<W1A<G1?;6%I;@!?7V=M;VY?<W1A
M<G1?7P!L:6)P97)L+G-O+C4N,30`7T193D%-24-?3$E.2TE.1P!?7U),1%]-
M05``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9G)E90!P
M97)L7V1E<W1R=6-T`'!E<FQ?86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`<&5R;%]P87)S90!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?<G5N`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!097)L
M7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?<V5T<'9N`%]*=E]296=I<W1E
M<D-L87-S97,`4&5R;%]A=E]F971C:`!097)L7VYE=UA37V9L86=S`%!E<FQ?
M;6=?<V5T`%!E<FQ?;F5W6%,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N
M97=35G!V`%!,7VUE;6]R>5]W<F%P`%!E<FQ?9W9?9F5T8VAP=@!097)L7W-A
M9F5S>7-M86QL;V,`4&5R;%]D;W5N=VEN9`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V`%!,7V1O7W5N9'5M<`!03%]T:')?:V5Y`%!E<FQ?879?
M<VAI9G0`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&-L
M;W-E`'!T:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!?
M7V5R<FYO7VQO8V%T:6]N`%]?<F5G:7-T97)?871F;W)K`&QI8F,N<V\N-@!O
M<&5N9&ER`&5X96-V<`!?7V-T>7!E7V)?;&]C`&%C8V5S<P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`'-T
M<G-T<@!S=')C:'(`<F5A9&QI;FL`<W1R;F-P>0!E>&ET`&9P<FEN=&8`7U]X
M<W1A=#8T`')M9&ER`&UK9&ER`&UE;6-H<@!S=')T;VL`<F5A9&1I<C8T`'-P
M<FEN=&8`;65M8W!Y`%]?<W1R9'5P`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!?7VQX<W1A=#8T`%])3U]S=&1I;E]U<V5D`')E86QL;V,`<W1D
M97)R`%]?96YV:7)O;@!L9"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R
M>7!T+G-O+C$`7V9T97AT`%]F9&%T80!?961A=&$`7U]B<W-?<W1A<G0`7V9B
M<W,`7V5N9`!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?:6YI=%]E;G8`>'-?:6YI=`!?9W!?9&ES<`!?7W-T87)T`%]?9VYU
M7VQO8V%L7V=P`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C``
M1TQ)0D-?,BXS`$=,24)#7S(N,RXR`````0`"``$``@`!``,``0`"``(``@`"
M``$``@`"``0``0```````0`"```````!``4``@````(```````(``@````$`
M`0`!``````````<``@````(``@`!`````@`!``$``0````(````"``(``0`'
M`````0```````@`"``(````!``,``@````(````!```````"``$``0`!````
M`0````$``@`!``$```````$``0`````````"``@``0`!`````@`"``@``P`(
M``$``P`"``$``@`!``D``@````8``0`!`,\#```0````(````!1I:0T```0`
M.`4````````!``(`1P(``!`````P````$FEI#0``!P!"!0``$````!!I:0T`
M``,`3`4````````!``4`J`(``!``````````$VEI#0``"0!6!0``$````!)I
M:0T```@`0@4``!````!R&6D)```&`&`%```0````%&EI#0``!0`X!0``$```
M`!!I:0T```(`3`4``````````````````#"]00!^"```.+U!`'X*``!`O4$`
M?@\``$2]00!^&@``2+U!`'X=``!,O4$`?C(``.R[00!_`@``\+M!`'\$``#T
MNT$`?P8``/B[00!_"0``_+M!`'\+````O$$`?PT```2\00!_#@``"+Q!`'\1
M```,O$$`?Q(``!"\00!_%```%+Q!`'\5```8O$$`?Q8``!R\00!_&```(+Q!
M`'\9```DO$$`?QL``"B\00!_'```++Q!`'\>```PO$$`?Q\``#2\00!_(```
M.+Q!`'\D```\O$$`?R4``$"\00!_)@``1+Q!`'\G``!(O$$`?R@``$R\00!_
M*0``4+Q!`'\J``!4O$$`?RL``%B\00!_+0``7+Q!`'\N``!@O$$`?S,``&2\
M00!_-```:+Q!`'\U``!LO$$`?S8``'"\00!_.```=+Q!`'\Y``!XO$$`?SL`
M`'R\00!_/```@+Q!`'\]``"$O$$`?SX``(B\00!_/P``C+Q!`']```"0O$$`
M?T(``)2\00!_0P``F+Q!`']$``"<O$$`?T4``*"\00!_1@``I+Q!`'](``"H
MO$$`?TD``*R\00!_2@``L+Q!`']2``"TO$$`?U4``+B\00!_5@``O+Q!`']:
M``#`O$$`?UL``,2\00!_7```R+Q!`']=``#,O$$`?V```-"\00!_80``U+Q!
M`']C``#8O$$`?V0``-R\00!_90``X+Q!`']G``#DO$$`?V@``.B\00!_:@``
M[+Q!`']L```"`!P\6":<)R'@F0/@_[TG'`"_KQ``O*\X@(*/)0@@``4`0!`E
M""``.("9CR4((``)^"`#)0@@``$`$00E""``HP<0#"4((``!`!$$)0@@`-05
M$`PE""``'`"_CR4((``(`.`#(`"])P````````````````````!"`!P\Y+N9
MC^2[G"<CP!P#(7C@`X+`&``)^"`#_O\8)T(`#SSLN_F-"``@`^R[^"5"``\\
M\+OYC0@`(`/PN_@E0@`///2[^8T(`"`#]+OX)4(`#SSXN_F-"``@`_B[^"5"
M``\\_+OYC0@`(`/\N_@E0@`//`"\^8T(`"`#`+SX)4(`#SP$O/F-"``@`P2\
M^"5"``\\"+SYC0@`(`,(O/@E0@`//`R\^8T(`"`##+SX)4(`#SP0O/F-"``@
M`Q"\^"5"``\\%+SYC0@`(`,4O/@E0@`//!B\^8T(`"`#&+SX)4(`#SP<O/F-
M"``@`QR\^"5"``\\(+SYC0@`(`,@O/@E0@`//"2\^8T(`"`#)+SX)4(`#SPH
MO/F-"``@`RB\^"5"``\\++SYC0@`(`,LO/@E0@`//#"\^8T(`"`#,+SX)4(`
M#SPTO/F-"``@`S2\^"5"``\\.+SYC0@`(`,XO/@E0@`//#R\^8T(`"`#/+SX
M)4(`#SQ`O/F-"``@`T"\^"5"``\\1+SYC0@`(`-$O/@E0@`//$B\^8T(`"`#
M2+SX)4(`#SQ,O/F-"``@`TR\^"5"``\\4+SYC0@`(`-0O/@E0@`//%2\^8T(
M`"`#5+SX)4(`#SQ8O/F-"``@`UB\^"5"``\\7+SYC0@`(`-<O/@E0@`//&"\
M^8T(`"`#8+SX)4(`#SQDO/F-"``@`V2\^"5"``\\:+SYC0@`(`-HO/@E0@`/
M/&R\^8T(`"`#;+SX)4(`#SQPO/F-"``@`W"\^"5"``\\=+SYC0@`(`-TO/@E
M0@`//'B\^8T(`"`#>+SX)4(`#SQ\O/F-"``@`WR\^"5"``\\@+SYC0@`(`.`
MO/@E0@`//(2\^8T(`"`#A+SX)4(`#SR(O/F-"``@`XB\^"5"``\\C+SYC0@`
M(`.,O/@E0@`//)"\^8T(`"`#D+SX)4(`#SR4O/F-"``@`Y2\^"5"``\\F+SY
MC0@`(`.8O/@E0@`//)R\^8T(`"`#G+SX)4(`#SR@O/F-"``@`Z"\^"5"``\\
MI+SYC0@`(`.DO/@E0@`//*B\^8T(`"`#J+SX)4(`#SRLO/F-"``@`ZR\^"5"
M``\\L+SYC0@`(`.PO/@E0@`//+2\^8T(`"`#M+SX)4(`#SRXO/F-"``@`[B\
M^"5"``\\O+SYC0@`(`.\O/@E0@`//,"\^8T(`"`#P+SX)4(`#SS$O/F-"``@
M`\2\^"5"``\\R+SYC0@`(`/(O/@E0@`//,R\^8T(`"`#S+SX)4(`#SS0O/F-
M"``@`]"\^"5"``\\U+SYC0@`(`/4O/@E0@`//-B\^8T(`"`#V+SX)4(`#SS<
MO/F-"``@`]R\^"5"``\\X+SYC0@`(`/@O/@E0@`//.2\^8T(`"`#Y+SX)4(`
M#SSHO/F-"``@`^B\^"5"``\\[+SYC0@`(`/LO/@ET/^])S``I*\T`*6O.`"F
MKS``I"<T`*4G.`"F)RP`OZ\H`+*O)`"QKT`&$`P@`+"O0``%/*`9I21```0\
M4!J$))(5$`PA,*``0@`"/$B]0H!7`$`00@`0/+0&$`Q$O02.'P1#D$2]!(X"
M`&,TM`80#!\$0Z`P`*2/'P1#D`4`A"0`$(1$`0!C-!\$0Z!?`(`$(1"`1@`0
M@$1```(\`!B`1"4((````")&^%M"U#P0($8E""``8P`!14(`!3PH!A`,@"`$
M`#0`HX\P`*:/``!DC$(`!SP``$2L0``$/+1;A"0$`$2L00`$/#1@A"0(`$2L
M0``$/+A;A"1TS>*L#`!$K`0`!R1"``0\`@#%*`D`H!1XS8>L(2A```$`!"0$
M`&>,`0"$)!``IZP$`&,D^_^&%`0`I20#`,8D@!@&`$(`$#PA&$,`@,T$CD``
M!3P``&"LH#JE)"$X0`"`!A`,$`"@KQ\`0!`AB$``!`80#(#-!(Y```0\NPP0
M#/18A"0<`$`00@`2//0%$`R`S02.=`80#"4((``L`+^/(1`@`B@`LH\D`+&/
M(`"PCP@`X`,P`+TG&`80#"4((`!"``,\'P!`$(#-8JPA($``\`40#$(`$#RT
M!A`,1+T$CN(&$`C<`T"@G`80#(#-!(XF!Q`((8A``'S-1(X)`(`0)0@@`$\5
M$`PE""``+0<0""4((`!```(\\%M"U/$&$`@``")&0``$/+L,$`R06(0D(2!`
M`-7_0!!\S4*N2P<0""4((``X!A`,`0`$)$``!#R(6H0D5`80#$R]I20`````
M```````````A`.`#`0`1!"4((`!"`!P\X#R<)R'X```8@(2/``"ECP0`IB?X
M_P$D).BA`^#_O2<<@(>/(("(CR4((``0`*BO%`"BKQ@`O:\T@)F/)0@@``GX
M(`,E""``__\`$"4((`#0_[TG*`"SKT(`$SQ@O6*2+`"_KR0`LJ\@`+&O&`!`
M%!P`L*]!`!(\00`1/`A@4B8,8#$F0@`0/".(,@)DO0*.@X@1`/__,28K&%$`
M"@!@$`$`0B2`&`(`(1A#`@``>8P)^"`#9+T"KF2]`HXK&%$`^/]@%`$`0B0!
M``(D8+UBHBP`OX\H`+./)`"RCR``L8\<`+"/"`#@`S``O2=!``0\$&""C`<`
M0!`E""`````9/```.2<#`"`3)0@@``@`(`,08(0D"`#@`R4((``E""``>/V]
M)X0"L:^``K"O.`"&)"$0H`.``*XG_P`'/```Q8P$`,.,`$H%``!"`P`"6@4`
M`&X%``!F`P`"4@,`)$@G`21`!P$E2"T!`/]K,25`#`$`_THQ)4@K`0(N!0`E
M0`H!`AX#`"4H)0$E&`,!``!%K`0`0*P(`$.L#`!`K!``0B3F_TX4"`#&)&@`
MHB=H`JPGV/]+C```18S<_TJ,!`!&C*C_28RL_TB,F/]#C)S_1XPF*&4!)C!&
M`28H)0$F,`8!)BAE`"8PY@#"'P4`0#`&`"48PP!`*`4`)1AE`!@`0ZP<`$"L
M"`!").G_3!0``*>/``"%C`0`C(P(`(B,(`"+C`P`C8P0`(F,&`"*C$!Q#`#"
M-@4`@EH"/)EY0C0A.&<!)3#&`2=X"`!`<04`@&\-`((8"``(`+"/)3#.`"1X
MZ@$D<"@!)1BC`2$XX@"`;P@`)6AM`"$XY@`E&.X!)W`%`"$XXP`D,*4!)'#)
M`2&`4`&`9PP`@A@%`!``N(\A@`("PGX'`"48@P$E,,X`@&<%`$!Q!P`E8&P`
M(3`&`B48[@$G@`<`(3##`"'`.`$D&.P`)(`-`A@`L8\AP`(#)8`#`D!Y!@#"
M'@8`@G`'`(`_!P`E<,<!)1AO`"$X$`,G>`8`(1CC`"&((@(D.,X`)'CL`2``
MN(\AB"T"0($#`"5XYP&":`8`PCX#`(`W!@`E:*8!(7@O`B4X\``G,`,`(3CG
M`2'``@,D>&T`)##.`"@`L8\AP`P#PH8'`"4PSP""8`,`0'D'`(`?`P`E8(,!
M(3`&`R48#P(G@`<`(3##`"&((@(D&.P`)(`-`C``N(\AB"X")8`#`D!Y!@#"
M'@8`@G`'`(`_!P`E<,<!)1AO`"$X,`(G>`8`(1CC`"'``@,D.,X`)'CL`3@`
ML8\AP`T#0($#`"5XYP&":`8`PCX#`(`W!@`E:*8!(7@/`R4X\``G,`,`(3CG
M`2&((@(D>&T`)##.`$``N(\AB"P"PH8'`"4PSP""8`,`0'D'`(`?`P`E8(,!
M(3`F`B48#P(G@`<`(3##`"'``@,D&.P`)(`-`D@`L8\AP`X#)8`#`D!Y!@#"
M'@8`@G`'`(`_!P`E<,<!)1AO`"$X$`,G>`8`(1CC`"&((@(D.,X`)'CL`5``
MN(\AB"T"0($#`"5XYP&":`8`PCX#`(`W!@`E:*8!(7@O`B4X\``G,`,`(3CG
M`2'``@,D>&T`)##.`%@`L8\AP`P#PH8'`"4PSP""8`,`0'D'`(`?`P`E8(,!
M(3`&`R48#P(G@`<`(3##`"&((@(D&.P`)(`-`F``N(\AB"X")8`#`D!Y!@#"
M'@8`@G`'`(`_!P`E<,<!)1AO`"$X,`(G>`8`(1CC`"'``@,D.,X`)'CL`6@`
ML8\AP`T#0($#`"5XYP&":`8`PCX#`(`W!@`E:*8!(7@/`R4X\``G,`,`(3CG
M`2&((@(D>&T`)##.`'``N(\AB"P"PH8'`"4PSP""8`,`0'D'`(`?`P`E8(,!
M(3`F`B48#P(G@`<`(3##`"'``@,D&.P`)(`-`G@`L8\AP`X#)8`#`D!Y!@#"
M'@8`@G`'`(`_!P`E<,<!)1AO`"$X$`,G>`8`(1CC`"&((@(D.,X`)'CL`8``
MN(\AB"T"0($#`"5XYP&":`8`PCX#`(`W!@`E:*8!(7@O`B4X\``G,`,`(3CG
M`22`;0`AP`(#)##.`(@`KX\AP`P#PHX'`"4PT`""8`,`0($'`(`?`P`E8(,!
M(3`&`R48,`(GB`<`(3##`"%XX@$D&.P`)(@M`I``L(\EB","@L`'`"%P[@'"
M'@8`0'D&`(`_!P`E.`<#(7#1`248;P`GB`8`(1C#`21XQP`A@`(")(@L`I@`
MKH\EB"\"@L`&`"%H#0)`>0,`PH8#`(`W!@`E,`8#)7@/`B%HL0$GB`,`(6BO
M`2$0P@$DB"<")'!F`*``KX\EB"X"PH8-`"%@3`!`<0T`@L@#`(#'`P#9;@(\
MH>M"-"48.`,E<`X"(6"1`2%@C@$A>.(!)HAF`*@`KH\FB"T"PH8,`(+`#0`A
M..<!@&\-`$!Y#``E:`T#)7@/`B$X\0`A..\`(7#"`2:(HP&P`*^/)H@L`L*&
M!P""P`P`(3#&`8!G#`!`<0<`)6`,`R5P#@(A,-$`(3#.`"%XX@$FP(T!N`"N
MCR;`!P/"C@8`0($&`"$8XP&">`<`@#\'`"5XYP$A&'@`)3@P`B$89P`A<,(!
M)CCL`<``N(\A:,T!PHX#`$"!`P`F..8`@G`&`(`W!@`E<,8!(3BG`24P,`(A
M..8`(<`"`R8PSP'(`*V/(<`,`\*.!P!`@0<`)C##`()@`P"`'P,`)6"#`2$P
M!@,E&#`"(3##`":(C@$A&*(!T`"XCR:()P)`@08`(7AO`()H!P#"'@8`@#\'
M`"5HIP$A>/$!)1AP`"$8XP$F.*P!(<`"`]@`L8\AP`X#PH8#`$!Y`P`F..8`
M@G`&`(`W!@`E<,8!(3@'`R4P#P(A..8`(8@B`B8PS0'@`+B/(8@L`L*&!P!`
M>0<`)C##`()@`P"`'P,`)6"#`2$P)@(E&`\"(3##`":`C@$AP`(#Z`"QCR'`
M#0,F@`<"0'D&`,(>!@"":`<`@#\'`"5HIP$E&&\`(3@0`R$8XP`AB"(")CBL
M`?``N(\AB"X"PH8#`$!Y`P`F..8`@G`&`(`W!@`E<,8!(3@G`B4P#P(A..8`
M(<`"`R8PS0'X`+&/(<`,`\*&!P!`>0<`)C##`()@`P"`'P,`)6"#`2$P!@,E
M&`\"(3##`":`C@$AB"("``&XCR&(+0(F@`<"0'D&`,(>!@"":`<`@#\'`"5H
MIP$E&&\`(3@P`B$8XP`AP`(#)CBL`0@!L8\AP`X#PH8#`$!Y`P`F..8`@G`&
M`(`W!@`E<,8!(3@'`R4P#P(A..8`(8@B`B8PS0$0`;B/(8@L`L*&!P!`>0<`
M)C##`()@`P"`'P,`)6"#`2$P)@(E&`\"(3##`":`C@$AP`(#&`&QCR'`#0,F
M@`<"0'D&`,(>!@"":`<`@#\'`"5HIP$E&&\`(3@0`R$8XP`AB"(")CBL`2`!
MN(\AB"X"PH8#`$!Y`P`F..8`@G`&`(`W!@`E<,8!(3@G`B4P#P(A..8`(<`"
M`R8PS0$H`;&/(<`,`\*&!P!`>0<`)C##`()@`P"`'P,`)6"#`2$P!@,E&`\"
M(3##`":`C@$AB"(",`&XCR&(+0(F@`<"0'D&`,(>!@"":`<`@#\'`"5HIP$E
M&&\`(3@P`B$8XP`AP`(#)CBL`3@!KX\AP`X#PHX#`$"!`P`F..8`@G`&`(`W
M!@`E<,8!(3@'`R4P,`(A..8`(1#B`2;`S0&">`,`@#<#`"4PY@%``;&/)L`#
M`\*&!P`A8$P`0'D'`!N/`CS<O$(T)7@/`B%@F`$E@,X`(6"/`2&((@(D>,X`
M)(#P`((8!P"`/P<`)1AG`$@!N(\E@`\"(6@M`L)^#`!`.0P`)3CG`2%HL`$E
M@&8`(6BG`21X9@`AP`(#)("0`8(X#`"`9PP`)3CL`%`!L8\E@`\"(7`.`\)^
M#0!`80T`)6#L`2%PT`$E@.,`(7#,`21XXP`AB"(")("P`8)@#0"`;PT`)6"-
M`5@!N(\E@`\"(3`F`D!Y#@#";@X`(3#0`"5HKP$E@(<!(6C-`"1XAP$AP`(#
M)(#0`8(P#@"`=PX`)3#.`&`!L8\E@`\"(1@#`T!Y#0#"=@T`(1AP`"5PSP$E
M@,P`(7!N`"1XS``AB"(")("P`8(8#0"`;PT`)1AM`&@!N(\E@`\"(3@G`D!Y
M#@#";@X`(3CP`"5HKP$E@&8`(6CM`"1X9@`AP`(#)(#0`8(X#@"`=PX`)3CN
M`'`!L8\E@`\"(6`,`T!Y#0#"=@T`(6"0`25PSP$E@.,`(7".`21XXP`AB"("
M)("P`8)@#0"`;PT`)6"-`7@!N(\E@`\"(3`F`D!Y#@#";@X`(3#0`"5HKP$E
M@(<!(6C-`"1XAP$AP`(#)(#0`8(P#@"`=PX`)3#.`(`!L8\E@`\"(1@#`T!Y
M#0#"=@T`(1AP`"5PSP$E@,P`(7!N`"1XS``AB"(")("P`8(8#0"`;PT`)1AM
M`(@!N(\E@`\"(3@G`D!Y#@#";@X`(3CP`"5HKP$E@&8`(6CM`"1X9@`AP`(#
M)(#0`8(X#@"`=PX`)3CN`)`!L8\E@`\"(6`,`T!Y#0#"=@T`(6"0`25PSP$E
M@.,`(7".`21XXP`AB"(")("P`8)@#0"`;PT`)6"-`9@!N(\E@`\"(3`F`D!Y
M#@#";@X`(3#0`"5HKP$E@(<!(6C-`"1XAP$AP`(#)(#0`8(P#@"`=PX`)3#.
M`*`!L8\E@`\"(1@#`T!Y#0#"=@T`(1AP`"5PSP$E@,P`(7!N`"1XS``AB"("
M)("P`8(8#0"`;PT`)1AM`*@!N(\E@`\"(3@G`D!Y#@#";@X`(3CP`"5HKP$E
M@&8`(6CM`"1X9@`AP`(#)(#0`8(X#@"`=PX`)3CN`+`!L8\E@`\"(6`,`T!Y
M#0#"=@T`(6"0`25PSP$E@.,`(7".`21XXP`AB"(")("P`8)@#0"`;PT`)6"-
M`;@!N(\E@`\"(3`F`D!Y#@#";@X`(3#0`"5HKP$E@(<!(6C-`"1XAP$AP`(#
M)(#0`8(P#@"`=PX`)3#.`,`!L8\E@`\"(1@#`T!Y#0#"=@T`(1AP`"5PSP$E
M@,P`(7!N`"1XS``AB"(")("P`8(8#0"`;PT`)1AM`,@!N(\E@`\"(3@G`D!Y
M#@#";@X`(3CP`"6(9@`E:*\!(6CM`"2`9@`AP`(#)(C1`8(X#@"`=PX`)3CN
M`-`!KX\EB#`"(6`,`\*&#0!`<0T`)7`.`B%@D0$E@.,`(6".`2%XX@$D<.,`
M@H@-`"2`L`&`;PT`)6@M`M@!N8\E@`X"(3#F`4!Q#`#"?@P`)7#N`27`IP$A
M,-``(3#.`"1XIP$A$"(#),"8`>`!KH\AR$,`)<`/`\*&!@""B`P`0'D&`(!G
M#`!BR@(\UL%"-"5@+`(A&#@#)7@/`B$8;P`A<,(!)LB-`>@!KX\FR"8#PH8#
M`"$XQP&"P`8`0'$#`(`W!@`EP`8#(3CY`"4P#@(A..8`(7CB`28P#`/P`:Z/
M(6CM`<+.!P!`@0<`)C##`()X`P"`'P,`)7CC`2$PI@$E&#`#(3##`";(^`$A
M&,(!^`&MCR;()P-`@08`(6!L`()P!P#"'@8`@#\'`"5PQP$A8)D!)1AP`"$8
M@P$F.,\!(6"B`2'`F`$``JV/PLX#`$"!`P`F..8`@F`&`(`W!@`E8(8!(3@'
M`R4P,`,A..8`(6BB`28PC@$(`KB/(7BO`<+.!P!`@0<`)C##`()H`P"`'P,`
M)6BC`2$PY@$E&#`#(3##`":`K`$AP`(#$`*YCR'`#@,F@`<"0'D&`,(>!@""
M<`<`@#\'`"5PQP$E&&\`(3@0`R$8XP`AR"(#)CC-`1@"N(\AR"P#PH8#`$!Y
M`P`F..8`@F`&`(`W!@`E8(8!(3@G`R4P#P(A..8`(<`"`R8PC@$@`KF/(<`-
M`\*&!P!`>0<`)C##`()H`P"`'P,`)6BC`2$P!@,E&`\"(3##`":`K`$AR"(#
M*`*XCR'(+@,F@`<"0'D&`,(>!@""<`<`@#\'`"5PQP$E&&\`(3@P`R$8XP`A
MP`(#)CC-`3`"N8\AP`P#PH8#`$!Y`P`F..8`@F`&`(`W!@`E8(8!(3@'`R4P
M#P(A..8`(<@B`R8PC@$X`KB/(<@M`\*&!P!`>0<`)C##`()H`P"`'P,`)6BC
M`2$P)@,E&`\"(3##`":`K`$AP`(#0`*YCR'`#@,F@`<"0'D&`,(>!@""<`<`
M@#\'`"5PQP$E&&\`(3@0`R$8XP`AR"(#)CC-`4@"N(\AR"P#PH8#`$!Y`P`F
M..8`@F`&`(`W!@`E8(8!(3@G`R4P#P(A..8`(<`"`R8PC@%0`KF/(<`-`\*&
M!P!`>0<`)C##`()H`P"`'P,`)6BC`2$P!@,E&`\"(3##`":`K`$AR"(#6`*X
MCR'(+@,F@`<"0'D&`,(>!@""<`<`@#\'`"5PQP$E&&\`(3@P`R$8XP`AP`(#
M)CC-`6`"N8\AP`P#PH8#`$!Y`P`F..8`@F`&`(`W!@`E8(8!(3@'`R4P#P(A
M..8`(<@B`R8PC@%H`J^/(<@M`\+&!P!`@0<`)C##`()H`P"`'P,`)6BC`2$P
M)@,E&!`#(3##`";`K`$A&.(!)L`'`W`"KX]`@08`@L@'`"%P;@"`/P<`PAX&
M`"4X)P,A<-@!)1AP`"$8PP$A>.(!)LCM`'@"KH\FR"8#PL8#`(*`!@`A8.P!
M@#<&`$!Y`P`E,`8")7@/`R%@F0$A8(\!(1#"`2;`QP`FP`,#(6A-`$!Y#`#"
M%@P`@G`#`"%HN`$E$$\`@!\#`"48PP$A$*(!(2A%`"%`B`$A2&D`(3#*`"$X
MZP```(6LA`*QCX`"L(\$`("L"`"(K`P`@*P0`(FL%`"`K!@`AJP<`("L(`"'
MK"0`@*P(`.`#B`*])\C_O2<P`+:O)`"SKS0`OZ\L`+6O*`"TKR``LJ\<`+&O
M&`"PKR&8@``D`(`0(;"@`$(``CPPO56,(`"@$B4((````(*`#`!`$"&0```]
M``,D"0!#$"4((``AD(```0!2)@``0H(#`$`0)0@@`/O_0Q0E""``(Y!3`@``
ML(X/```2(8B@`CT`%"0A(``"(2A@`JP&$`PA,$`"!`!`%"$8$@(``&*`$`!4
M$`$`0B8$`#$F```PCO7_`!8A(``"-`"_CR$0```P`+:/+`"UCR@`M(\D`+./
M(`"RCQP`L8\8`+"/"`#@`S@`O2<CB#4"@X@1````T:XT`+^/(1`"`C``MH\L
M`+6/*`"TCR0`LX\@`+*/'`"QCQ@`L(\(`.`#.`"])]C_O2<D`+^O<PP0#!P`
MI2<D`+^/"`#@`R@`O2?0_[TG*`"QKR0`L*\L`+^O(8"``$(`$3PA(``"<PP0
M#!P`I2<3`$`0+`"_CQP`HH\PO2..@!`"`"$08@`$`$.,]?]@$```0ZP(`$(D
M``!#C/S_0ZS]_V`4!`!")"$@``)S#!`,'`"E)_'_0!0<`**/+`"_CR@`L8\D
M`+"/"`#@`S``O2?8_[TG&`"PKT(`$#Q$O02.)`"_KR``LJ^T!A`,'`"QK_0!
M0HQ$O02.M`80#`0`48Q$O02.M`80#-0#4I`$`$*,?P!2,A``0HS_`4(PP!$"
M`"600@("`#*FM`80#$2]!([T`4*,1+T$CK0&$`P$`%&,0``%/+!;I20A,```
M4`80#"$@0`!$O02.M`80#!P`(J[T`4*,1+T$CK0&$`P$`%&,U`1"C$2]!(ZT
M!A`,(``BKO0!0HQ$O02.M`80#`0`48P$!T*,!0!`$"$0``"T!A`,1+T$C@0'
M0HQP`$*,1+T$CK0&$`PD`"*N]`%"C$2]!(X$`$*,M`80#"@`0*ST`4*,1+T$
MC@0`0HRT!A`,&`!`K/0!0HQ$O02.M`80#`0`4(S\`4*,+``"KB0`OX\@`+*/
M'`"QCQ@`L(\(`.`#*`"])RC_O2>X`+"OU`"_K]``MJ_,`+6OR`"TK\0`LZ_`
M`+*OO`"QKP0`@!`A@(````""@`L`0!0E""``U`"_C]``MH_,`+6/R`"TC\0`
MLX_``+*/O`"QC[@`L(\(`.`#V`"])\0&$`PE""``\_]`$"&(0`!``!4\+@`2
M)"18M2;__Q0DI`80#"$@(`(3`%8D)@!`$"$@``(3`$.0,0!R$"4((`!$!A`,
M)0@@`"$@P`)$!A`,(9A``"$08@(P!A`,`@!$)"&80``A.,`"(2!``"$HH`*@
M!A`,(3```@,`!"0A*&`"L`80#!@`IB<&`%00(2!@`C``HX\`0`(D`/!C,"(`
M8A`E""````80#"4((`#<!1`,(2!@`J0&$`PA("`"$P!6)-S_0!0A(``"P`80
M#"$@(`+L!1`,(2```M0`OX_0`+:/S`"UC\@`M(_$`+./P`"RC[P`L8^X`+"/
M"`#@`]@`O2<4`$.0QO]@$"4((`#,_W(4)0@@`!4`0I#!_T`0)0@@`%L-$`@E
M""``,PT0#"4((`!V#1`()0@@`-C_O2<<`+"O0@`0/"``L:\AB(``1+T$CB0`
MOZ^T!A`,)0@@`&``1B0#``0DN`80#"$H(`(&`$`0)`"_CR$0```@`+&/'`"P
MCP@`X`,H`+TGM`80#$2]!(YX`$.,`$`")`#P8S`)`&(0(2`@`K0&$`Q$O02.
M>`!#C`"@`C0`\&,P[O]B%"0`OX\A("`"B`80#`(`!20D`+^/`0!"+"``L8\<
M`+"/"`#@`R@`O2>X_[TG*`"QKR0`L*]$`+^O0`"WKSP`MJ\X`+6O-`"TKS``
MLZ\L`+*O``"B@#T``R0A@*``60!#$"&(@`!$!A`,(2```B$@(`(<`*4G<PP0
M#"&80`!3`$`0(9!``$0&$`PA($``*Q!3`$``0!`<`+6/0@`4/("H%0```"*"
M<0!`$#T``R1O`$,0(1`@`NL-$`@]``0D!0!D$"4((``!`$(D``!#@/O_8!0E
M""``(R!1`#"]@HX"`',F(2!D`C`&$`PAJ%4`9`!`$```HJY"``(\,+U#C!P`
MHH^`$`(`(1!B````0XP``"*"#0!`$```8J`]``0D"P!$$#T``B0'#A`(`0`Q
M)@<`1!`]``(D```B@@$`8R0``&*@^O]`%`$`,28]``(D``!BH`$`8R0```*"
M`0`0)@``8J#\_T`4`0!C)$0`OX]``+>//`"VCS@`M8\T`+2/,`"SCRP`LH\H
M`+&/)`"PCP@`X`-(`+TG```"@@$`$"8``$*B\?]`$`$`4B8```*"`0`0)@``
M0J+W_T`4`0!2)A4.$`A$`+^/TPT0"`$`L"1"`!0\,+V7C@``XHXF`$`0!`#B
M)B&0```$`$(D_/]#C/W_8!0!`%(F`@!%)H`H!0!"``(\<+U#C`T`8!`!``,D
M+`80#"$@X`(AL$``&0!`$#"]@JZ`J!(``0!")H`0`@`AL,("``#`KN(-$`@<
M`+*O(2"@`#`&$`QPO4.L#0!`$"&P0`"`J!(`(2!``"$HX`+8!1`,(3"@`D,.
M$`@PO9:N\`T0""$@```(``4D.0X0""&0```4#A`(__\"),COO2<D$+"O0@`0
M/"P0LJ]`O0*.(9"``$``!#PP$+.O+%B$)"&8H`#_#P8D'`"E)S00OZ\H$+&O
M'!"BKPP&$`PE""``'P!`&"`0I"?__U$D(1B1`/SO8X`8`&`0'`"D)R&(0``O
M``4D<`80#"$P(`(4`$`00@`"/+0&$`Q$O42,(2!``"$H0`(<`*8GF`80#"$X
M(`(<$*./0+T"CA(`8A0T$+^/,!"SCRP0LH\H$+&/)!"PCP@`X`,X$+TGZ?\@
M%B4((`!"``(\M`80#$2]1(PA($``(2A``A`&$`PA,&`"@0X0""4((`#X!1`,
M)0@@`$(``CQ$O42,X/^])QP`OZ^T!A`,)0@@`$``!3Q```8\0``'/!P`OX\A
M($``/%BE)*`7QB186.<D6`80""``O2?8_[TG(`"PKT(`$#Q$O02.)`"_K[0&
M$`PE""``F`X0#"$@0`"T!A`,1+T$CD```SRP6V,D0``%/$``!CPA($``9%BE
M)`!1QB0A.&``$`"CKX0&$`P4`*"O)`"_CR``L(\(`.`#*`"])\C?O2<H(+"O
M0@`0/$"]`HXT(+^O,""RKRP@L:\D(**O)`80#"4((`!```4\0``'/!P`I"=\
M6*4D(3!``*`&$`R(6.<D&@!`!!P`I"<@$*4G#`80#``0!B05`$`$(9!``#`&
M$`P!`$0D!P!`$"&(0``A,$`"(2!``"`0I2?@!1`,(9`R`@``0*(D(*2/0+T#
MC@D`@Q0A$"`"-""_CS`@LH\L(+&/*""PCP@`X`,X(+TGY`X0""&(``#X!1`,
M)0@@`,(.$`@E""``J.^])U`0OJ]"`!X\.!"RKT"]PH\AD(``0``$/)!8A"14
M$+^O-!"QKS`0L*],$+>O(8"@`$@0MJ]$$+6O0!"TKSP0LZ\L$**ONPP0#"4(
M(``A($`"+P`%)#P&$`PAB$``%0!`$"$@0`)```0\G%B$),0-$`PA*$`"+!"D
MCT"]PX]=`(,4(1!``E00OX]0$+Z/3!"WCT@0MH]$$+6/0!"TCSP0LX\X$+*/
M-!"QCS`0L(\(`.`#6!"])T0&$`Q``!0\(2```JQ8A2:,!A`,(:A``.7_0!`A
M,$``0``7/$``%CPO`!`DL%CW)KA8UB9"`!,\``#"@`(`0!1```(\C%A&)`8`
M(!(A*,``(2`@`LP%$`PD`*:O)@!`$"0`IH\A(,``1`80#"0`IJ\D`*:/(1C"
M`/__9(`&`)`4)0@@`/__8*#__V,D__]D@/S_D!#__T(D`0!")"$050``$$(H
MPO]`$"$HX`(A.,`"+`"D)Z`&$`P0`+*OM`80#$2]9(Y@`$8D`P`$)+`&$`PL
M`*4G"0!`%"$@``"T!A`,1+UDCG@`0XP`@`(T`/!C,`@`8A`L`*0G(2```(P&
M$`RL6(4FS/]`%"$P0``/#Q`(0``$/(@&$`P!``4D]O]`%$``!#R<6(0DQ`T0
M#"P`I2=D!A`,+`"D)Q(/$`@AD$``^`40#"4((````(6`#0"@$`$`@R0A$(``
M+P`&)`<`IA`E""```0!C)/__98#[_Z`4)0@@``@`X`,E""``>P\0""$08``(
M`.`#(1"``-C_O2<@`+&O)`"_KQP`L*\@`(`0(8B`````@H`=`$`0)0@@`$0&
M$`PE""``__]&)"$P)@(K$"8"*@!`$"\``B0``,.`'@!B%"4((`"=#Q`(+P`#
M)```PH`9`$,4)0@@`/__QB3[_]$4)0@@````PX`O``(D-0!B$$``!#PD`+^/
M(`"QCQP`L(^X6(0D9`80""@`O2<P!A`,`@`$)`,`0!!```,\C%ACE```0Z0D
M`+^/(`"QCQP`L(\(`.`#*`"])[H/$`@O``,D``#"@`4`0Q`E""``___&)"L0
M)@+Z_T`4)0@@`.'_T1`O``,D___&)"L0)@($`$`0)0@@````PH#Z_T,0)0@@
M`",PT0`"`,(D`1!"+`L`0!!"`!`\=+T$)B$H(`)X!A`,`0#&)"0`OX]TO0(F
M(`"QCQP`L(\(`.`#*`"])[`/$`@A$```,`80#`(`!"3[_T`0(1A``$```CR,
M6$24(1!@`+`/$`@``&2DJ/^])T``L*]"`!`\0+T"CD```SS`6V,D/`"BKU0`
MOZ]0`+2O3`"SKT@`LJ]$`+&O&`"B)R``9"0``&B,!`!GC`@`9HP,`&6,$`!C
M)```2*P$`$>L"`!&K`P`1:SV_V04$`!")```8Y1```0\``!#I,(,$`R\6(0D
M0``$/,(,$`S(6(0D0``$/,(,$`S06(0D0``$/-Q8A"3"#!`,0``1/,(,$`SD
M6"0F0``$//18A"1``!,\P@P0#$``$CR06&0FP@P0#$``%#S"#!`,`%E$)L(,
M$`P,680F0``$/,(,$`P8680D0``$/,(,$`R<6(0D0``$/,(,$`PD680D0``$
M/,(,$`PP680D0``$/+L,$`P\680D`P!`$"$H0`#$#1`,#%F$)D``!#R[#!`,
M4%F$)`4`0!`E""``0``$/&19A"3$#1`,(2A``$``!#R[#!`,<%F$)!,`0!!`
M``0\D%AD)L0-$`PA*$``0``%/.18)";$#1`,H%FE)#P`HX]`O0*.&P!B%%0`
MOX]0`+2/3`"SCT@`LH]$`+&/0`"PCP@`X`-8`+TGNPP0#(!9A"0%`$`0`%E$
M)L0-$`PA*$``/!`0"$``!3Q```4\*0"D)Y19I22L!A`,"@`&)./_0!0`640F
MQ`T0##,`I2<\$!`(0``%//@%$`PE""``X/^])Q@`L*]!`!`\,&`"CO__`R0%
M`$,0'`"_KQP`OX\8`+"/"`#@`R``O2=```0\NPP0#`!9A"0+`$`0)0@@````
M0H`(`$`0)0@@`#``0C@K$`(`,&`"KAP`OX\8`+"/"`#@`R``O2<A$```=1`0
M"#!@`J[@_[TG'`"_K_P%$`PE""``U`40#"$@0``%`$`0)0@@````0HP<`+^/
M"`#@`R``O2>%$!`((1```$```CR@_[TGM%E")"@`HJ]```(\O%E")"P`HJ]`
M``(\Q%E")#``HJ]```(\S%E")$0`L:\T`**O0``1/$```CQ4`+6O4`"TKZ19
M,2;@64(D0``5/$``%#Q,`+.O2`"RKUP`OZ]8`+:O0`"PKR&8@``D`+&O.`"B
MKSP`H*\H`+(GL%BU)K40$`BL6)0FR`40#"4((``>`$`0)0@@``0`4B;\_U&.
M$0`@$EP`OX^[#!`,(2`@`B&`0``A*&`"!`!`$"$@0````$*`\/]`%"4((``A
M("`"(2A@`L0-$`P$`%(F_/]1CO'_(!9<`+^/6`"VCU0`M8]0`+2/3`"SCT@`
MLH]$`+&/0`"PCP@`X`-@`+TG1`80#"$@8`(A(``"1`80#"&P0``A$,(",`80
M#`(`1"0AL$``(2!``"$HH`(A,&`"(3B``J`&$`P0`+"O(2`@`L0-$`PA*,`"
MLA`0"`0`4B80@+TGT'^RKT(`$CS@?[:OW'^UK]A_M*_4?[.O['^_K^A_OJ_D
M?[>OS'^QK\A_L*]`O4*.F/Z])RR!`S0A&'T```!BK$```CS\64(D4`"BKT``
M`CR,6$(D5`"BKT```CQH64(D/`"BKT```CP$6D(D0`"BKT```CR46$(D1`"B
MKT```CP,6D(D2`"BKT``%#Q``!8\0``3/$```CP06D(D9%G6)NQ9<R8AJ(``
MD%B$)E@`H*\X`+:O3`"@KUP`LZ]@`**ONPP0#&0`H*\$`$`0)0@@````0X`.
M`6`4(2!``'P0$`PE""``$0%`$"&`0````!&"$@`@$C"!!33(!A`,)0@@`"$8
M``)?``4D``!$C$"($0`AB)$````DE@@`A#`"`(`4)0@@````9:`!`&,D``!Q
M@/7_(!8E""``,($%-/__$SPA*+T`(9BS``Q_<R8\$1`((2#``@0`<R;\_V2.
M$@"`$#"!MB>[#!`,)0@@`/G_0!`AB$````!"@/;_0!`E""``F0T0#"$@(`+S
M_T`0!`!S)OS_<R9D!A`,(2`@`AH`0!0A,$``,(&V)R!_T8X6`"`2(3``````
M(H)2`$`0`0`3)%T1$`@E""``@!`3`"$0P@(@?U&,#``@$B$P`````"*"2`!`
M$`$`<R:9#1`,(2`@`O;_0!"`$!,`9`80#"$@(`+Q_T`0(3!``"$@P`!$!A`,
M*`"FKR$@``)$!A`,(;!``"&PP@($!-8F,`80#"$@P`(A($``(8A``"@`IH]`
M`!,\0``%/$```CP<6J4DN%AG)BA:0B00`**OH`80#!0`L*\A("`"8`80#,`!
M!23__P,D)@!#$"4((`!"`!`\M`80#$2]!(Y@`$8D`P`$)+@&$`PA*"`"+0!`
M$$(``CPXO42,``"FCD``!3RX6J4D(3@@`D@&$`PA@```+($)-"%(/0$``"2-
M0+U#CJ@"@Q0A$``":`&])^Q_OX_H?[Z/Y'^WC^!_MH_<?[6/V'^TC]1_LX_0
M?[*/S'^QC\A_L(\(`.`#\'^])V41$`@A,```;`80#"4((````$*,$0`#)-;_
M0Q!"``,\``"FCCB]9(Q```4\,%JE)"$X(`(0`**O2`80#"&```"2$1`(+($)
M-+0&$`Q$O02.>`!#C`!``B0`\&,PSO]B%$(``CRT!A`,1+T$COP%$`R``%>,
MR/_B%D(``CRT!A`,1+T$CG@`0XS``0(D_P%C,,'_8A1"``(\,`80#"$@P`)`
M``0\Q%F$)+L,$`PA@$``=@!`$"$@0`!D!A`,``"VCB$H0`#T#A`,(2#``F\`
M0!`AL$``1`80#"$@P`(AN$``!`!"*`T`0!3\_^0F0``%/"$@Q`+,!1`,;%JE
M)`<`0!0$``(D^0'B$B&XUP+[_^."+P`")/4!8A`E""``7Q`0#"4((``'`$`4
M0``$/"$@P`),!A`,(2@``%8`0!0AJ$``0``$/$``!3P`680DQ`T0#*!9I20D
M!A`,0``7/$``!3RX6&<FL%OW)B$@``*46J4D(3`@`A``HJ\4`+>OH`80#"&H
M``#__Q8D$0`>)!D2$`BX6',F;`80#"4((````$*,$0!>%"4((``D!A`,`0"U
M)D``!3PA(``"I%JE)"$P(`(A.&`"$`"BKQ0`M:^@!A`,&`"WKR$@``)@!A`,
MP`$%).S_5A`E""``W`40#"$@(`*06(0FQ`T0#"$H``**$!`,(2```I(1$`@L
M@0DTBA`0#"@`HJ\H`**/9`80#"$@0`"1$1`((8!```$`$20W$A`((2!@`H`0
M$0`P@:0G(1""`"Q_1(P.`(`0`0`Q)KL,$`PE""``]_]`$"4((````$.`]/]@
M$"4((`!D!A`,(2!``/#_0!`A@$``'Q$0"```$8)``!`\,1$0"/19$";9$1`(
M``"VCN[_!B3__P<D(2!```(`'B3__Q8\(`80#!``OJ\P@08T(3#=`#A_UR8A
MN-<`(2"@`B$HX`+0!1`,!@`&)&@`HI,$`$`4:0"BDT,``R3'`4,0:@"DDR$@
MH`(A,```(3@``"`&$`P0`*"O16<"/&B`!S0A./T``2-"-```XJQP@`@TS>\"
M/(FK0C0A0!T!```"K7B`"32ZF`(\(1@``/[<0C0A2#T!!`#CK```(JTA&```
M,A`"/("`&31V5$(T(<@]`P0``ZTA&```!``CK0``(J\A&```TL,"/(B`'C0A
M\-T#\.%"-`0`(Z\A&`````#"KP0`PZ^0@`0TF(`%-."`!C3__QX\,($'-"$0
M```A&```(2"=`"$HO0`A,-T`.'_>)R$X_0```(*L!`"#K```HJP$`*.L``#`
MK"'P_@`A(*`"(2C``]`%$`P`@`8T?@!`&"&P0`"0@`@TE(`)-"%`'0$A2#T!
M```"C0``(XW`,!8`PR<6`"T!8!0A,,(`*Q#"`"L!0!28@`,TF(`9-)R`'S0A
MR#T#(?C]`P``(H\``.6/P#@$`$(?%@`E&.,`X(`(-)B`'S0A&$,`0B<$`"%`
M'0$A^/T#*Q!B`"$HI`"0@`DTE(`9-```XZ\```2-G(`#-"$010`A2#T!(<@]
M`R$8?0```":M```@KP@!@!```&*L0``%)",0I``J*%8``@"@$"$8P`(A&$``
MH(`&-"&XI@,A(.0"(3!@`"$HP`/@!1`,*`"CK^"`!S0A./T```#BC"@`HX]`
M``@D(1!B`+O_2!0``.*L:(`$-"$@G0"P!Q`,*`"CKR@`HX\CL,,"(2C#`T``
MPBHH`$`40`"C),#_UB:"R18`@!$9`"$08@`T`+:O,`"YKRP`HJ\AL*``(1#@
M`D``R"8#`,>*!P#&B@L`Q(H/`,.*``#'F@0`QIH(`,2:#`##FA``UB8``$>L
M!`!&K`@`1*P,`$.L\O_(%A``0B1H@`0T(2"=`+`'$`PH`*6O+`"BC^G_PA8H
M`*6/,`"CCS0`IH\!`&(D@!$"`("Q`P`A**(`([#6`"$PP`+@!1`,(2#@`N"`
M!S0A./T```#VK"$@H`(A*,`#T`40#`"`!C2$_T`<(;!``+P&$`PA(*`"D(`(
M-"%`'0$``!6-,($)-,(0%0`_`$(P`0!#)"%(/0&8@!DT(2`B`2'(/0.`_P4D
M.0!C*```-H]P_X6@P@!@$#D`1"1H@`4T(2B]`#<`!B0A(*0`(S#"`%P&$`PA
M*```V(`)--F`&33:@!XT`D86``(\%@`",A8`(<@]`R%(/0$A\-T#```HH0``
M)Z,``,:CVX`?--R`!C3=@`<TWH`(--^`"30"+A4``AP5``(2%0`A^/T#(3#=
M`"$X_0`A0!T!(4@]`6B`!#0``/:C``#%H```XZ````*A```UH;`'$`PA()T`
M:(`9-"'(/0-X@!\T```GCR'X_0.`@`(TB(`&-```Y(\A$%T`(3#=`!B!'S0`
M`$.,(?C]`P``PHQP@!XT`C8'````YJ,A\-T#&8$?-```Q8\A^/T#`O0'````
M_J,;@1\T(?C]`QJ!'C0``.>C`LH'`"'PW0,<@0<T``#9HP+&!0`A./T`'H$>
M-`*R!0```/B@(?#=`QV!&30?@1\T(8$'-```UJ,"O`4``GP$`"'(/0,A^/T#
M(3C]`".!'C0``#>C``#EHP``[Z`A\-T#(($%-"*!&30D@1\T)X$'-`*N!```
M`,2C`G($``)N`P`A*+T`(<@]`R'X_0,E@00T(3C]`"F!'C0``+6@`F0#``):
M`P```"ZC``#MHR$@G0`A\-T#`DP"`":!!30``..@*($9-"J!'S0K@0,T`E8"
M``)"`@```(R@(2B]`"'(/0,``,FC(?C]`R$8?0#L@`0T0``>/```JZ```"JC
M``#HHP``8J`AL```(:BD`XQ:WB>[$Q`(%``7)!B!!30A*+T`(1"V````1I!`
M(!8`(2"D`B$HP`.@!A`,`0#6)O;_UQ84@0@T0``%/"%`'0$```"A(2```GQ:
MI20A,"`"N%AG)A``M:]```(\L%M")*`&$`P4`**O'A(0""4((`"@@`DT(2C`
M`^42$`@AN*D#F(`#-"$8?0```&*,G(`'-"$X_0`!`$,D``#EC"L08@`A*$4`
ML1(0""$08``$`+6."OZ@$B4((`!$!A`,(2"@`@0`0RP%_F`4_/]")$``!3PA
M(*("S`40#'1:I23__4`4)0@@`.L1$`@AL*`":(`>-"'PW0,_``8D(2#$`R$H
M``!<!A`,(S#"`&B`!#2P!Q`,(2"=`*"`'S2D@`(TJ(`#-"'X_0,A$%T`(1A]
M````X*\``$"L``!@K*R`!#2P@`4TM(`&-+B`!S2\@`@TP(`)-,2`&33(@!XT
MS(`?--"``C34@`,T(2"=`"$HO0`A,-T`(3C]`"%`'0$A2#T!(<@]`R'PW0,A
M^/T#(1!=`"$8?0```("L``"@K```P*P``."L````K0``(*T``""O``#`KP``
MX*\``$"L-1,0"```8*Q!``,D./Z#%&L`HY,V_F(4;`"CDT@``B0S_F(4;0"C
MDT4``B0P_F(4__\'),;_!B0A(*`"(`80#!``OJ\A(*`"(2C@`M`%$`PI``8D
M0``%/"$@``)\6J4D(3`@`KA89R;*$Q`($`"WK_@%$`PE""``N/^])R@`LJ]"
M`!(\1+U$CD0`OZ]``+ZO/`"WKS@`MJ\T`+6O,`"TKRP`LZ\D`+&OM`80#"``
ML*\!``,D0``$/-4#0Z"[#!`,Y%B$)`0`0!`Q``,D``!$@*X`@Q`E""``X0\0
M#"4((`"T!A`,1+U$CD``!3PA($``#%NE)`$`!B0T!A`,"P`')#0`0!`AB```
M0@`4/'C-@XX0`$2,`@!B*"L`0!08`)6,`0`0)$(`%SQW%!`(0@`6/!``18S,
M!1`,(2!@`B(`0!1XS8..`0`0)BH0`P(>`$`0`0`Q)K0&$`Q$O42.(2!``"$H
MH`(A,"`"D`80#"$X``"``$`0(?!`````0HQTS<6."`!#C(`@$``A(*0```1C
M,.?_8!0``).,M`80#$2]Y(X``,6/(2!``"$P```4!A`,`@`')"$H0`#,!1`,
M(2!@`N#_0!!XS8..__]B)%,`41`"`&,H1+U$CK0&$`Q"`!`\0``%/"$@0``4
M6Z4D`0`&)#0&$`P$``<D$`!`$"&(0`"T!A`,1+T$CA``(XY```8\``!EC"$@
M0``0!A`,&%O&)!``(HX``$*,"`!#C$```CPD$&(`1P!`%"4((`!$O42.M`80
M#$(`$3Q```4\(2!``"!;I20!``8D-`80#`0`!R0-`$`0(8!``$``!#R[#!`,
MG%B$)&8`0!!$O22.M`80#!P`HJ\0``..'`"FCP``98P0!A`,(2!``$2]1(ZT
M!A`,0@`3/$2]1(ZT!A`,U0-`H$``!#Q,!4"LNPP0#)!8A"0W`$`0?,UBKB$@
M0`!@!A`,P`$%)`4`0!`1``,D`P!#$/__`R1L`$,40@`#/$0`OX]``+Z//`"W
MCS@`MH\T`+6/,`"TCRP`LX\H`+*/)`"QCR``L(\(`.`#2`"])ZW_8!0!`!`D
M1+U$CK0&$`P!`!`F(2!``.0%$`PA**`">,V"CBH0`@+W_T`41+U$CI@4$`@E
M""``M`80#$2]!(X0`"..(2!``'P&$`P``&6,LA00"$2]1(YXS8..__]B));_
M411$O42.Z100"`(`8R@!`$*`4_]`$"4((`!8%!`()0@@`$(`$3SB$!`,=,TD
MCC<`0!!\S6*N$``"C@``0HP(`$.,``1C,!P`8!`E""``$`!$C`@&$`QTS26.
M$``#CG3-)(X``&.,(8A```@`8HP`!$(P'`!`$```DXP0`&:,0``$/$A;A"0A
M*&`"5`80#"$X(`*T!A`,)0@@`$(``CP0``..=,U"C```9(Q<#A`,``!%C,D4
M$`A$O42.0@`"/+0&$`Q$O42,$``#CB$@0````&6,(3```!0&$`P"``<D%A40
M""$@0`"T!A`,1+U$CA```XXA,`````!EC"$@0``4!A`,`@`')"$5$`@A,$``
M0``$/%0&$`PD6X0D=,UCC$``!#P``&6,?,UFCG!;A"14!A`,(3A``-C_O2<@
M`+&O)`"_KR&(@`"%#Q`,'`"PKP``1(`>`(`0`0!#)"&`0``O``(D&`""$"4(
M(``!`&,D__]D@/O_@!0E""``7Q`0#"4((``,`$`0)`"_CPH`(!(E""`````B
M@@<`0!`A(``"0``%/,@%$`PH6J4D"@`"$B$@(`(D`+^/(`"QCQP`L(\(`.`#
M*`"])UP5$`@A@&``8!40""&`0``D`+^/(`"QCQP`L(\S#1`(*`"])^#_O2<8
M`+"O0@`0/$2]!(X<`+^OM`80#"4((``A($``'`80#/__!22T!A`,1+T$CD``
M!3P<`+^/&`"PCR$@0`",,Z4D(3```*@&$`@@`+TG``````````!``!D\4%8Y
M)P(`'#R0YIPG(>"9`R2`@H\E""``!@!`$"4((````$>,/("9CR4((``(`"`#
M)0@@`/O_`!`A.```)0@@`"4((``(`.`#)0@@``(`'#Q(YIPG(>"9`\C_O2<T
M`+^O,`"UKRP`M*\H`+.O)`"RKR``L:\<`+"O$`"\KRB`F8\AF(``(:"@``GX
M(`,AJ,``$`"\CR4((``L@)&/+("2CR4((``CD%$"@Y`2``H`0!(A@``````Y
MC@$`$"8A(&`"(2B``@GX(`,A,*`"*Q`2`OC_0!0$`#$F-`"_CS``M8\L`+2/
M*`"SCR0`LH\@`+&/'`"PCP@`X`,X`+TG)0@@`"4((`!!``(\`&!9C-C_O2?_
M_P(D)`"_KR``L:\)`"(3'`"PKT$`$#P`8!`F__\1)`GX(`/\_Q`F```9COS_
M,1<E""``)`"_CR``L8\<`+"/"`#@`R@`O2<E""``)0@@`"4((``0@)F/(7C@
M`PGX(`-O`!@D$("9CR%XX`,)^"`#;0`8)``````````````````````"`!P\
M`.6<)R'@F0/@_[TG'`"_KQ``O*\!`!$$)0@@`'P'$`PE""``'`"_CR4((``(
M`.`#(`"])P```````````0`"`"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0
M`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`
M````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#
M2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'
M`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)
M0E)!4EE?4$%42````%-(3$E"7U!!5$@``%5315(`````4UE35$5-```O=&UP
M`````%1%35!$25(`5$U0`%5315).04U%`````"5S)7,E<R5S`````'!A<BT`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``<&%R;``````N<&%R`````"5S)7-C86-H92TE
M<R5S```E,#)X`````"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``$%2
M1U8`````&````'!E<FP`````,````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@
M9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0```````%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````````````````````
M`````````/!!``"`____ST$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_____P````#_____````````````````````````````````````
M````````````_____R,A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@
M+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C
M;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@
M(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P
M96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD
M:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U
M<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T
M:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@
M=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN
M("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R
M;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L
M:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL
M:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD
M('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R
M;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S
M(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A
M:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC
M;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@
M("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@
M<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*
M("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@
M("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.
M('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV
M*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6
M>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*
M("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@
M?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R
M;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@
M("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C
M:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T
M('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L
M("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY
M("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*
M("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE
M(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C
M:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@
M7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[
M4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@
M("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C
M<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE
M+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS
M=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@
M("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@
M("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O
M<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@
M;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@
M("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@
M("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D
M9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`]
M(%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69]
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD[
M"@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C
M(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@
M;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET
M:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F
M('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@
M9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I
M<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U
M<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I
M;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@
M<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I
M=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D
M:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@
M(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@
M("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@
M("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@
M+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@
M("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN
M<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H
M8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A
M;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC
M.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@
M("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S
M:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E
M("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@
M>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@
M("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]
M("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@
M("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?
M;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`
M05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@
M(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@
M("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@
M861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D
M92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R
M97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A
M<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@
M("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T[
M"@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L
M;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@
M("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@
M("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@
M4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]
M"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@
M(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@
M(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@
M("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@
M("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@
M("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@
M("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R
M:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@
M(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@
M>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*
M"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@
M/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A
M*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@
M;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@
M97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C
M($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP
M<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES
M(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I
M<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H
M92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@
M("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S
M.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]
M*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L
M=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D
M;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE
M(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO
M861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@
M("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*
M("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI
M"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@
M("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@
M("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@
M("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@
M("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*
M("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA
M9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@
M("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@
M("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA
M;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@
M("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2
M.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@
M("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@
M('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@
M("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@
M("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@
M("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@
M("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@
M("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@
M("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@
M268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY
M("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@
M("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E
M<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E
M($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/
M.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#
M;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@
M("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D
M('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S
M:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*
M(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S
M971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@
M*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@
M("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y
M=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@
M("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H
M+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L
M(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@
M("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@
M("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D
M("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O
M+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@
M("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG
M97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q
M.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T
M96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D
M9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D
M8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@
M('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U
M<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M
M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE
M;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G
M;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@
M("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@
M?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U
M<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P
M<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA
M:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?
M<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@
M("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M.PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@
M>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@
M("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T
M<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@
M("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R![
M"B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@
M("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F
M;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*
M,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*````````````````````````````
M`````!=````70```%T```!=````70```%T```!=````70```%T```!=````7
M0```%T```!=````70```%T```!=````70```%T```!=````70```%T```!=`
M```70```%T```!=````70```%T```!=````70```%T```!=````70```%T``
M`!=````70```%T```!=````70```%T```!=````70```%T```!=````70```
M%T```!=````70```%T```!=````70```%T```!=````70```%T```!=````7
M0```%T```!=````70```%T```!=````70```%T```!=````70```````````
M@#`;0`"85D``D%9``""]00"(%D```&!!``````#`5T```````+!70```````
M1T-#.B`H1&5B:6%N(#0N-BXR+30I(#0N-BXR`$=#0SH@*$1E8FEA;B`T+C0N
M-BTQ,2D@-"XT+C8`````P!Y``````P#\____``````````"(`@``'0```!\`
M``#,,4````!_@/S___\``````````#@````=````'P```.PR0`````"`_/__
M_P``````````*````!T````?````"#-``````X#\____```````````P````
M'0```!\```",,T`````'@/S___\``````````"@````=````'P```,PT0```
M`'^`_/___P``````````V````!T````?````9#9``````X#\____````````
M```H````'0```!\````0-T````#_@/S___\``````````$@````=````'P``
M`'`Y0`````^`_/___P``````````.!```!T````?````8#I``````(#\____
M```````````@````'0```!\```"@.D`````!@/S___\``````````"@````=
M````'P````@[0`````>`_/___P``````````."```!T````?````R#M`````
M````````````````````````'0```!\```#0.T````#_P/S___\`````````
M`%@0```=````'P```-`]0````````````````````````````!T````?````
M%#Y``````X#\____```````````H````'0```!\```"$/T`````?@/S___\`
M`````````%@````=````'P```'Q!0`````&`_/___P``````````(````!T`
M```?````\$%``````(#\____```````````@````'0```!\````H0D````!_
M@/S___\``````````&`````=````'P```(A#0````/_`_/___P``````````
M6($``!T````?`````%%`````_\#\____``````````!(````'0```!\````\
M54`````#@/S___\``````````"@````=````'P```/!50`````&`_/___P``
M````````(````!T````?````,!M`````!X#\____```````````P````'0``
M`!\```!05D`````````````````````````````=````'P```)!60```````
M`````````````````````!T````?````F%9`````/X#\____```````````X
M````'0```!\```!!#P```&=N=0`!!P````0!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD+6ED`"YD
M>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+DU)
M4%,N<W1U8G,`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD871A`"YR;&1?;6%P`"YG;W0N<&QT`"YG;W0`+G-D871A`"YB
M<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T=')I8G5T97,`+FUD96)U9RYA8FDS
M,@`````````````````````````````````````````````````````````+
M`````0````(```!4`4``5`$```T```````````````$`````````$P````<`
M```"````9`%``&0!```@```````````````$`````````"$````&``!P`@``
M`(0!0`"$`0``&```````````````!````!@````J````!P````(```"<`4``
MG`$``"0```````````````0`````````/0````8````"````P`%``,`!``!`
M`0``"``````````$````"````$8````%`````@`````#0````P``3`,```<`
M````````!`````0```!,````"P````(```!,!D``3`8````'```(`````0``
M``0````0````5`````,````"````3`U``$P-``!L!0`````````````!````
M`````%P```#___]O`@```+@20`"X$@``X`````<``````````@````(```!I
M````_O__;P(```"8$T``F!,``+`````(`````P````0`````````>`````D`
M```"````2!1``$@4```X````!P`````````$````"````($````)`````@``
M`(`40`"`%```"`(```<````.````!`````@```"*`````0````8```"(%D``
MB!8``&@```````````````0`````````A0````$````&`````!=````7```P
M!``````````````@`````````)`````!````!@```#`;0``P&P``@#P`````
M````````$`````````"6`````0````8```"P5T``L%<``#``````````````
M``0`````````H@````$````&````X%=``.!7```X```````````````$````
M`````*@````!`````@```"!80``@6```X`,`````````````$`````````"P
M`````0````(`````7$```%P```0```````````````0`````````N@````$`
M```#`````&!!``!@```(```````````````$`````````,$````!`````P``
M``A@00`(8```"```````````````!`````````#(`````0````,````08$$`
M$&````0```````````````0`````````S0````$````#````(&!!`"!@``#`
M6P`````````````0`````````-,````!`````P```."[00#@NP``!```````
M````````!`````````#<`````0````,```#DNT$`Y+L```P!````````````
M``0`````````Y0````$````#```0\+Q!`/"\```P```````````````0````
M!````.H````!`````P``$""]00`@O0``!```````````````!`````````#Q
M````"`````,````PO4$`)+T``&`0`````````````!``````````]@````$`
M```P`````````"2]```Y```````````````!`````0```/\````!````````
M``````!@O0``@`,`````````````!``````````$`0``]?__;P``````````
MX,```!````````````````$`````````%`$```$`````````D,U!`/#`````
M```````````````!``````````$````#``````````````#PP```(@$`````
.`````````0``````````
